@@ -273,6 +273,7 @@ def write_delta_stream_no_partitioning(spark_job_conf: dict, output_name: str, s
 
 def write_delta_stream_with_custom_fnc(spark_job_conf, output_name: str, stream: DataFrame, updater_function):
     output_stream_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
+    create_delta_tables_if_not_exists_no_partitioning(output_stream_conf, output_stream_conf['delta_options']['schema'])
 
     if output_stream_conf.get('processing_time') is not None:
         stream \
@@ -426,3 +427,9 @@ def to_avro_abris_config(config_map, topic, is_key):
         .downloadSchemaByLatestVersion() \
         .andTopicNameStrategy(topic, is_key) \
         .usingSchemaRegistry(scala_map)
+
+
+def instanciate_delta_table(spark_session: SparkSession, spark_job_conf: dict, table_name: str):
+    table_conf = get_spark_conf(table_name, spark_job_conf['outputs'])
+    create_delta_tables_if_not_exists(table_conf, table_conf['delta_options']['schema'])
+    return DeltaTable.forPath(spark_session, table_conf['delta_options']['location'])
